# pip-start
![PyPI - Version](https://img.shields.io/pypi/v/pip-start?label=Version)
![PyPI - License](https://img.shields.io/pypi/l/pip-start?label=License)
![GitHub Release Date](https://img.shields.io/github/release-date/Veillax/pip-start?label=Release%20Date)
![PyPI - Downloads](https://img.shields.io/pypi/dm/pip-start?label=Downloads)

pip-start is a custom package I worte to allow simple and seamless auto-updating of packages that need it, such as game API Wrappers.
